package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcTenderMapper;
import com.ruoyi.oa.domain.CmcTender;
import com.ruoyi.oa.service.ICmcTenderService;

/**
 * 投标管理Service业务层处理
 * 
 * @author cmc
 * @date 2024-03-14
 */
@Service
public class CmcTenderServiceImpl implements ICmcTenderService 
{
    @Autowired
    private CmcTenderMapper cmcTenderMapper;

    /**
     * 查询投标管理
     * 
     * @param tenderId 投标管理主键
     * @return 投标管理
     */
    @Override
    public CmcTender selectCmcTenderByTenderId(String tenderId)
    {
        return cmcTenderMapper.selectCmcTenderByTenderId(tenderId);
    }

    /**
     * 查询投标管理列表
     * 
     * @param cmcTender 投标管理
     * @return 投标管理
     */
    @Override
    public List<CmcTender> selectCmcTenderList(CmcTender cmcTender)
    {
        return cmcTenderMapper.selectCmcTenderList(cmcTender);
    }

    /**
     * 新增投标管理
     * 
     * @param cmcTender 投标管理
     * @return 结果
     */
    @Override
    public int insertCmcTender(CmcTender cmcTender)
    {
        return cmcTenderMapper.insertCmcTender(cmcTender);
    }

    /**
     * 修改投标管理
     * 
     * @param cmcTender 投标管理
     * @return 结果
     */
    @Override
    public int updateCmcTender(CmcTender cmcTender)
    {
        return cmcTenderMapper.updateCmcTender(cmcTender);
    }

    /**
     * 批量删除投标管理
     * 
     * @param tenderIds 需要删除的投标管理主键
     * @return 结果
     */
    @Override
    public int deleteCmcTenderByTenderIds(String[] tenderIds)
    {
        return cmcTenderMapper.deleteCmcTenderByTenderIds(tenderIds);
    }

    /**
     * 删除投标管理信息
     * 
     * @param tenderId 投标管理主键
     * @return 结果
     */
    @Override
    public int deleteCmcTenderByTenderId(String tenderId)
    {
        return cmcTenderMapper.deleteCmcTenderByTenderId(tenderId);
    }
}
